@@ -1,20 +1,14 @@
-from __future__ import division, print_function, unicode_literals, absolute_import
-
-# THIRD-PARTY
+"""
+STScI Python compatable blot module
+"""
 import numpy as np
 
-# LOCAL
-from . import util
 from . import calc_pixmap
 from . import cdrizzle
 
 
-"""
-STScI Python compatable blot module
-"""
-
-def doblot(source, source_wcs, blot_wcs, exptime, coeffs = True,
-            interp='poly5', sinscl=1.0, stepsize=10, wcsmap=None):
+def doblot(source, source_wcs, blot_wcs, exptime, coeffs=True,
+           interp='poly5', sinscl=1.0, stepsize=10, wcsmap=None):
     """
     Low level routine for performing the 'blot' operation.
 
@@ -72,14 +66,13 @@ def doblot(source, source_wcs, blot_wcs, exptime, coeffs = True,
     _outsci = np.zeros(blot_wcs.pixel_shape[::-1], dtype=np.float32)
 
     # compute the undistorted 'natural' plate scale
-    wcslin = blot_wcs
     blot_wcs.sip = None
     blot_wcs.cpdis1 = None
     blot_wcs.cpdis2 = None
     blot_wcs.det2im = None
 
     pixmap = calc_pixmap.calc_pixmap(blot_wcs, source_wcs)
-    pix_ratio = source_wcs.pscale/blot_wcs.pscale
+    pix_ratio = source_wcs.pscale / blot_wcs.pscale
 
     cdrizzle.tblot(source, pixmap, _outsci, scale=pix_ratio, kscale=1.0,
                    interp=interp, exptime=exptime, misval=0.0, sinscl=sinscl)
