@@ -1,31 +1,20 @@
-import sys
 import math
 import os
-import shutil
-import tempfile
-import pytest
 
 import numpy as np
-import numpy.ma as ma
-import numpy.testing as npt
-
 from astropy import wcs
 from astropy.io import fits
 
-from drizzle import drizzle
+from drizzle import drizzle, cdrizzle
+
 
 TEST_DIR = os.path.abspath(os.path.dirname(__file__))
 DATA_DIR = os.path.join(TEST_DIR, 'data')
-OUTPUT_DIR = os.environ.get('DRIZZLE_TEST_OUTPUT_DIR', tempfile.mkdtemp())
 
-@pytest.yield_fixture(autouse=True, scope='module')
-def output_dir():
-    yield
-    if 'DRIZZLE_TEST_OUTPUT_DIR' not in os.environ:
-        shutil.rmtree(OUTPUT_DIR)
 
 ok = False
 
+
 def bound_image(image):
     """
     Compute region where image is non-zero
@@ -37,6 +26,7 @@ def bound_image(image):
     xmax = coords[1].max()
     return (ymin, ymax, xmin, xmax)
 
+
 def centroid(image, size, center):
     """
     Compute the centroid of a rectangular area
@@ -53,26 +43,30 @@ def centroid(image, size, center):
             center[1] += x * image[y,x]
             center[2] += image[y,x]
 
-    if center[2] == 0.0: return None
+    if center[2] == 0.0:
+        return None
 
     center[0] /= center[2]
     center[1] /= center[2]
     return center
 
+
 def centroid_close(list_of_centroids, size, point):
     """
     Find if any centroid is close to a point
     """
-    for i in range(len(list_of_centroids)-1, -1, -1):
+    for i in range(len(list_of_centroids) - 1, -1, -1):
         if (abs(list_of_centroids[i][0] - point[0]) < int(size / 2) and
-            abs(list_of_centroids[i][1] - point[1]) < int(size / 2)):
+                abs(list_of_centroids[i][1] - point[1]) < int(size / 2)):
             return 1
 
     return 0
 
+
 def centroid_compare(centroid):
     return centroid[1]
 
+
 def centroid_distances(image1, image2, amp, size):
     """
     Compute a list of centroids and the distances between them in two images
@@ -81,7 +75,8 @@ def centroid_distances(image1, image2, amp, size):
     list_of_centroids = centroid_list(image2, amp, size)
     for center2 in list_of_centroids:
         center1 = centroid(image1, size, center2)
-        if center1 is None: continue
+        if center1 is None:
+            continue
 
         disty = center2[0] - center1[0]
         distx = center2[1] - center1[1]
@@ -92,6 +87,7 @@ def centroid_distances(image1, image2, amp, size):
     distances.sort(key=centroid_compare)
     return distances
 
+
 def centroid_list(image, amp, size):
     """
     Find the next centroid
@@ -105,6 +101,7 @@ def centroid_list(image, amp, size):
 
     return list_of_centroids
 
+
 def centroid_statistics(title, fname, image1, image2, amp, size):
     """
     write centroid statistics to compare differences btw two images
@@ -115,7 +112,7 @@ def centroid_statistics(title, fname, image1, image2, amp, size):
 
     diff = []
     distances = centroid_distances(image1, image2, amp, size)
-    indexes = (0, int(len(distances)/2), len(distances)-1)
+    indexes = (0, int(len(distances) / 2), len(distances) - 1)
     fd = open(fname, 'w')
     fd.write("*** %s ***\n" % title)
 
@@ -127,7 +124,8 @@ def centroid_statistics(title, fname, image1, image2, amp, size):
         diff = [distances[0][0], distances[0][0], distances[0][0]]
 
         fd.write("1 match\n")
-        fd.write("distance = %f flux difference = %f\n" % (distances[0][0], distances[0][1]))
+        fd.write("distance = %f flux difference = %f\n" %
+                 (distances[0][0], distances[0][1]))
 
         for j in range(2, 4):
             ylo = int(distances[0][j][0]) - 1
@@ -136,7 +134,8 @@ def centroid_statistics(title, fname, image1, image2, amp, size):
             xhi = int(distances[0][j][1]) + 2
             subimage = images[j][ylo:yhi,xlo:xhi]
             fd.write("\n%s image centroid = (%f,%f) image flux = %f\n" %
-                     (im_type[j], distances[0][j][0], distances[0][j][1], distances[0][j][2]))
+                     (im_type[j], distances[0][j][0], distances[0][j][1],
+                      distances[0][j][2]))
             fd.write(str(subimage) + "\n")
 
     else:
@@ -145,7 +144,8 @@ def centroid_statistics(title, fname, image1, image2, amp, size):
         for k in range(0,3):
             i = indexes[k]
             diff.append(distances[i][0])
-            fd.write("\n%s distance = %f flux difference = %f\n" % (stats[k], distances[i][0], distances[i][1]))
+            fd.write("\n%s distance = %f flux difference = %f\n" %
+                     (stats[k],distances[i][0], distances[i][1]))
 
             for j in range(2, 4):
                 ylo = int(distances[i][j][0]) - 1
@@ -154,12 +154,14 @@ def centroid_statistics(title, fname, image1, image2, amp, size):
                 xhi = int(distances[i][j][1]) + 2
                 subimage = images[j][ylo:yhi,xlo:xhi]
                 fd.write("\n%s %s image centroid = (%f,%f) image flux = %f\n" %
-                         (stats[k], im_type[j], distances[i][j][0], distances[i][j][1], distances[i][j][2]))
+                         (stats[k], im_type[j], distances[i][j][0],
+                          distances[i][j][1], distances[i][j][2]))
                 fd.write(str(subimage) + "\n")
 
     fd.close()
     return tuple(diff)
 
+
 def make_point_image(input_image, point, value):
     """
     Create an image with a single point set
@@ -168,6 +170,7 @@ def make_point_image(input_image, point, value):
     output_image[point] = value
     return output_image
 
+
 def make_grid_image(input_image, spacing, value):
     """
     Create an image with points on a grid set
@@ -175,13 +178,14 @@ def make_grid_image(input_image, spacing, value):
     output_image = np.zeros(input_image.shape, dtype=input_image.dtype)
 
     shape = output_image.shape
-    half_space = int(spacing/2)
+    half_space = int(spacing / 2)
     for y in range(half_space, shape[0], spacing):
         for x in range(half_space, shape[1], spacing):
             output_image[y,x] = value
 
     return output_image
 
+
 def print_wcs(title, wcs):
     """
     Print the wcs header cards
@@ -189,6 +193,7 @@ def print_wcs(title, wcs):
     print("=== %s ===" % title)
     print(wcs.to_header_string())
 
+
 def read_image(filename):
     """
     Read the image from a fits file
@@ -200,6 +205,7 @@ def read_image(filename):
     hdu.close()
     return image
 
+
 def read_wcs(filename):
     """
     Read the wcs of a fits file
@@ -210,13 +216,15 @@ def read_wcs(filename):
     hdu.close()
     return the_wcs
 
-def test_square_with_point():
+
+def test_square_with_point(tmpdir):
     """
     Test do_driz square kernel with point
     """
+    output = str(tmpdir.join('output_square_point.fits'))
+    output_difference = str(tmpdir.join('difference_square_point.txt'))
+
     input_file = os.path.join(DATA_DIR, 'j8bt06nyq_flt.fits')
-    output = os.path.join(OUTPUT_DIR, 'output_square_point.fits')
-    output_difference = os.path.join(OUTPUT_DIR, 'difference_square_point.txt')
     output_template = os.path.join(DATA_DIR, 'reference_square_point.fits')
 
     insci = read_image(input_file)
@@ -234,19 +242,56 @@ def test_square_with_point():
         driz.write(output)
         template_data = read_image(output_template)
 
-        (min_diff, med_diff, max_diff) = centroid_statistics("square with point", output_difference,
-                                                                  driz.outsci, template_data, 20.0, 8)
+        min_diff, med_diff, max_diff = centroid_statistics("square with point",
+                                                           output_difference,
+                                                           driz.outsci,
+                                                           template_data, 20.0, 8)
 
-        assert(med_diff < 1.0e-6)
-        assert(max_diff < 1.0e-5)
+        assert med_diff < 1.0e-6
+        assert max_diff < 1.0e-5
 
-def test_square_with_grid():
+
+def test_zero_input_weight(tmpdir):
     """
     Test do_driz square kernel with grid
     """
+    insci = np.ones((200, 400), dtype=np.float32)
+    inwht = np.ones((200, 400), dtype=np.float32)
+    inwht[:, 150:155] = 0
+    tflux = np.sum(inwht)
+    pixmap = np.moveaxis(np.mgrid[1:201, 1:401][::-1], 0, -1)
+
+    for kernel in ['square', 'point', 'turbo']:
+        # initialize output:
+        outsci = np.zeros((210, 410), dtype=np.float32)
+        outwht = np.zeros((210, 410), dtype=np.float32)
+        outcon = np.zeros((210, 410), dtype=np.int32)
+
+        _vers, nmiss, nskip = cdrizzle.tdriz(
+            insci, inwht, pixmap,
+            outsci, outwht, outcon,
+            uniqid=1,
+            xmin=0, xmax=400,
+            ymin=0, ymax=200,
+            pixfrac=1,
+            kernel=kernel,
+            in_units='cps',
+            expscale=1,
+            wtscale=1,
+            fillstr='INDEF'
+        )
+
+        assert np.allclose(np.sum(outsci), tflux)
+
+
+def test_square_with_grid(tmpdir):
+    """
+    Test do_driz square kernel with grid
+    """
+    output = str(tmpdir.join('output_square_grid.fits'))
+    output_difference = str(tmpdir.join('difference_square_grid.txt'))
+
     input_file = os.path.join(DATA_DIR, 'j8bt06nyq_flt.fits')
-    output = os.path.join(OUTPUT_DIR, 'output_square_grid.fits')
-    output_difference = os.path.join(OUTPUT_DIR, 'difference_square_grid.txt')
     output_template = os.path.join(DATA_DIR, 'reference_square_grid.fits')
 
     insci = read_image(input_file)
@@ -264,19 +309,22 @@ def test_square_with_grid():
         driz.write(output)
         template_data = read_image(output_template)
 
-        (min_diff, med_diff, max_diff) = centroid_statistics("square with grid", output_difference,
-                                                                  driz.outsci, template_data, 20.0, 8)
+        min_diff, med_diff, max_diff = centroid_statistics("square with grid",
+                                                           output_difference,
+                                                           driz.outsci,
+                                                           template_data, 20.0, 8)
+        assert med_diff < 1.0e-6
+        assert max_diff < 1.0e-5
 
-        assert(med_diff < 1.0e-6)
-        assert(max_diff < 1.0e-5)
 
-def test_turbo_with_grid():
+def test_turbo_with_grid(tmpdir):
     """
     Test do_driz turbo kernel with grid
     """
+    output = str(tmpdir.join('output_turbo_grid.fits'))
+    output_difference = str(tmpdir.join('difference_turbo_grid.txt'))
+
     input_file = os.path.join(DATA_DIR, 'j8bt06nyq_flt.fits')
-    output = os.path.join(OUTPUT_DIR, 'output_turbo_grid.fits')
-    output_difference = os.path.join(OUTPUT_DIR, 'difference_turbo_grid.txt')
     output_template = os.path.join(DATA_DIR, 'reference_turbo_grid.fits')
 
     insci = read_image(input_file)
@@ -294,19 +342,23 @@ def test_turbo_with_grid():
         driz.write(output)
         template_data = read_image(output_template)
 
-        (min_diff, med_diff, max_diff) = centroid_statistics("turbo with grid", output_difference,
-                                                                  driz.outsci, template_data, 20.0, 8)
+        min_diff, med_diff, max_diff = centroid_statistics("turbo with grid",
+                                                           output_difference,
+                                                           driz.outsci,
+                                                           template_data, 20.0, 8)
 
-        assert(med_diff < 1.0e-6)
-        assert(max_diff < 1.0e-5)
+        assert med_diff < 1.0e-6
+        assert max_diff < 1.0e-5
 
-def test_gaussian_with_grid():
+
+def test_gaussian_with_grid(tmpdir):
     """
     Test do_driz gaussian kernel with grid
     """
+    output = str(tmpdir.join('output_gaussian_grid.fits'))
+    output_difference = str(tmpdir.join('difference_gaussian_grid.txt'))
+
     input_file = os.path.join(DATA_DIR, 'j8bt06nyq_flt.fits')
-    output = os.path.join(OUTPUT_DIR, 'output_gaussian_grid.fits')
-    output_difference = os.path.join(OUTPUT_DIR, 'difference_gaussian_grid.txt')
     output_template = os.path.join(DATA_DIR, 'reference_gaussian_grid.fits')
 
     insci = read_image(input_file)
@@ -324,19 +376,23 @@ def test_gaussian_with_grid():
         driz.write(output)
         template_data = read_image(output_template)
 
-        (min_diff, med_diff, max_diff) = centroid_statistics("gaussian with grid", output_difference,
-                                                                  driz.outsci, template_data, 20.0, 8)
+        min_diff, med_diff, max_diff = centroid_statistics("gaussian with grid",
+                                                           output_difference,
+                                                           driz.outsci,
+                                                           template_data, 20.0, 8)
 
-        assert(med_diff < 1.0e-6)
-        assert(max_diff < 2.0e-5)
+        assert med_diff < 1.0e-6
+        assert max_diff < 2.0e-5
 
-def test_lanczos_with_grid():
+
+def test_lanczos_with_grid(tmpdir):
     """
     Test do_driz lanczos kernel with grid
     """
+    output = str(tmpdir.join('output_lanczos_grid.fits'))
+    output_difference = str(tmpdir.join('difference_lanczos_grid.txt'))
+
     input_file = os.path.join(DATA_DIR, 'j8bt06nyq_flt.fits')
-    output = os.path.join(OUTPUT_DIR, 'output_lanczos_grid.fits')
-    output_difference = os.path.join(OUTPUT_DIR, 'difference_lanczos_grid.txt')
     output_template = os.path.join(DATA_DIR, 'reference_lanczos_grid.fits')
 
     insci = read_image(input_file)
@@ -354,19 +410,22 @@ def test_lanczos_with_grid():
         driz.write(output)
         template_data = read_image(output_template)
 
-        (min_diff, med_diff, max_diff) = centroid_statistics("lanczos with grid", output_difference,
-                                                                  driz.outsci, template_data, 20.0, 8)
+        min_diff, med_diff, max_diff = centroid_statistics("lanczos with grid",
+                                                           output_difference,
+                                                           driz.outsci,
+                                                           template_data, 20.0, 8)
+        assert med_diff < 1.0e-6
+        assert max_diff < 1.0e-5
 
-        assert(med_diff < 1.0e-6)
-        assert(max_diff < 1.0e-5)
 
-def test_tophat_with_grid():
+def test_tophat_with_grid(tmpdir):
     """
     Test do_driz tophat kernel with grid
     """
+    output = str(tmpdir.join('output_tophat_grid.fits'))
+    output_difference = str(tmpdir.join('difference_tophat_grid.txt'))
+
     input_file = os.path.join(DATA_DIR, 'j8bt06nyq_flt.fits')
-    output = os.path.join(OUTPUT_DIR, 'output_tophat_grid.fits')
-    output_difference = os.path.join(OUTPUT_DIR, 'difference_tophat_grid.txt')
     output_template = os.path.join(DATA_DIR, 'reference_tophat_grid.fits')
 
     insci = read_image(input_file)
@@ -384,19 +443,22 @@ def test_tophat_with_grid():
         driz.write(output)
         template_data = read_image(output_template)
 
-        (min_diff, med_diff, max_diff) = centroid_statistics("tophat with grid", output_difference,
-                                                                  driz.outsci, template_data, 20.0, 8)
+        min_diff, med_diff, max_diff = centroid_statistics("tophat with grid",
+                                                           output_difference,
+                                                           driz.outsci,
+                                                           template_data, 20.0, 8)
+        assert med_diff < 1.0e-6
+        assert max_diff < 1.0e-5
 
-        assert(med_diff < 1.0e-6)
-        assert(max_diff < 1.0e-5)
 
-def test_point_with_grid():
+def test_point_with_grid(tmpdir):
     """
     Test do_driz point kernel with grid
     """
+    output = str(tmpdir.join('output_point_grid.fits'))
+    output_difference = str(tmpdir.join('difference_point_grid.txt'))
+
     input_file = os.path.join(DATA_DIR, 'j8bt06nyq_flt.fits')
-    output = os.path.join(OUTPUT_DIR, 'output_point_grid.fits')
-    output_difference = os.path.join(OUTPUT_DIR, 'difference_point_grid.txt')
     output_template = os.path.join(DATA_DIR, 'reference_point_grid.fits')
 
     insci = read_image(input_file)
@@ -414,19 +476,22 @@ def test_point_with_grid():
         driz.write(output)
         template_data = read_image(output_template)
 
-        (min_diff, med_diff, max_diff) = centroid_statistics("point with grid", output_difference,
-                                                                  driz.outsci, template_data, 20.0, 8)
+        min_diff, med_diff, max_diff = centroid_statistics("point with grid",
+                                                           output_difference,
+                                                           driz.outsci,
+                                                           template_data, 20.0, 8)
+        assert med_diff < 1.0e-6
+        assert max_diff < 1.0e-5
 
-        assert(med_diff < 1.0e-6)
-        assert(max_diff < 1.0e-5)
 
-def test_blot_with_point():
+def test_blot_with_point(tmpdir):
     """
     Test do_blot with point image
     """
+    output = str(tmpdir.join('output_blot_point.fits'))
+    output_difference = str(tmpdir.join('difference_blot_point.txt'))
+
     input_file = os.path.join(DATA_DIR, 'j8bt06nyq_flt.fits')
-    output = os.path.join(OUTPUT_DIR, 'output_blot_point.fits')
-    output_difference = os.path.join(OUTPUT_DIR, 'difference_blot_point.txt')
     output_template = os.path.join(DATA_DIR, 'reference_blot_point.fits')
 
     outsci = read_image(input_file)
@@ -445,18 +510,22 @@ def test_blot_with_point():
         driz.write(output)
         template_data = read_image(output_template)
 
-        (min_diff, med_diff, max_diff) = centroid_statistics("blot with point", output_difference,
-                                                                  driz.outsci, template_data, 20.0, 16)
-        assert(med_diff < 1.0e-6)
-        assert(max_diff < 1.0e-5)
+        min_diff, med_diff, max_diff = centroid_statistics("blot with point",
+                                                           output_difference,
+                                                           driz.outsci,
+                                                           template_data, 20.0, 16)
+        assert med_diff < 1.0e-6
+        assert max_diff < 1.0e-5
 
-def test_blot_with_default():
+
+def test_blot_with_default(tmpdir):
     """
     Test do_blot with default grid image
     """
+    output = str(tmpdir.join('output_blot_default.fits'))
+    output_difference = str(tmpdir.join('difference_blot_default.txt'))
+
     input_file = os.path.join(DATA_DIR, 'j8bt06nyq_flt.fits')
-    output = os.path.join(OUTPUT_DIR, 'output_blot_default.fits')
-    output_difference = os.path.join(OUTPUT_DIR, 'difference_blot_default.txt')
     output_template = os.path.join(DATA_DIR, 'reference_blot_default.fits')
 
     outsci = read_image(input_file)
@@ -475,19 +544,23 @@ def test_blot_with_default():
         driz.write(output)
         template_data = read_image(output_template)
 
-        (min_diff, med_diff, max_diff) = centroid_statistics("blot with defaults", output_difference,
-                                                                  driz.outsci, template_data, 20.0, 16)
+        min_diff, med_diff, max_diff = centroid_statistics("blot with defaults",
+                                                           output_difference,
+                                                           driz.outsci,
+                                                           template_data, 20.0, 16)
 
-        assert(med_diff < 1.0e-6)
-        assert(max_diff < 1.0e-5)
+        assert med_diff < 1.0e-6
+        assert max_diff < 1.0e-5
 
-def test_blot_with_lan3():
+
+def test_blot_with_lan3(tmpdir):
     """
     Test do_blot with lan3 grid image
     """
+    output = str(tmpdir.join('output_blot_lan3.fits'))
+    output_difference = str(tmpdir.join('difference_blot_lan3.txt'))
+
     input_file = os.path.join(DATA_DIR, 'j8bt06nyq_flt.fits')
-    output = os.path.join(OUTPUT_DIR, 'output_blot_lan3.fits')
-    output_difference = os.path.join(OUTPUT_DIR, 'difference_blot_lan3.txt')
     output_template = os.path.join(DATA_DIR, 'reference_blot_lan3.fits')
 
     outsci = read_image(input_file)
@@ -506,19 +579,22 @@ def test_blot_with_lan3():
         driz.write(output)
         template_data = read_image(output_template)
 
-        (min_diff, med_diff, max_diff) = centroid_statistics("blot with lan3", output_difference,
-                                                                  driz.outsci, template_data, 20.0, 16)
+        min_diff, med_diff, max_diff = centroid_statistics("blot with lan3",
+                                                           output_difference,
+                                                           driz.outsci,
+                                                           template_data, 20.0, 16)
+        assert med_diff < 1.0e-6
+        assert max_diff < 1.0e-5
 
-        assert(med_diff < 1.0e-6)
-        assert(max_diff < 1.0e-5)
 
-def test_blot_with_lan5():
+def test_blot_with_lan5(tmpdir):
     """
     Test do_blot with lan5 grid image
     """
+    output = str(tmpdir.join('output_blot_lan5.fits'))
+    output_difference = str(tmpdir.join('difference_blot_lan5.txt'))
+
     input_file = os.path.join(DATA_DIR, 'j8bt06nyq_flt.fits')
-    output = os.path.join(OUTPUT_DIR, 'output_blot_lan5.fits')
-    output_difference = os.path.join(OUTPUT_DIR, 'difference_blot_lan5.txt')
     output_template = os.path.join(DATA_DIR, 'reference_blot_lan5.fits')
 
     outsci = read_image(input_file)
@@ -537,28 +613,28 @@ def test_blot_with_lan5():
         driz.write(output)
         template_data = read_image(output_template)
 
-        (min_diff, med_diff, max_diff) = centroid_statistics("blot with lan5", output_difference,
-                                                                  driz.outsci, template_data, 20.0, 16)
+        min_diff, med_diff, max_diff = centroid_statistics("blot with lan5",
+                                                           output_difference,
+                                                           driz.outsci,
+                                                           template_data, 20.0, 16)
+        assert med_diff < 1.0e-6
+        assert max_diff < 1.0e-5
 
-        assert(med_diff < 1.0e-6)
-        assert(max_diff < 1.0e-5)
 
-if __name__ == "__main__":
-    """
-    Run tests from command line
-    """
-    for flag in sys.argv[1:]:
-        if flag == 'ok':
-            ok = True
+def test_context_planes():
+    """Reproduce error seen in issue #50"""
+    shape = [10, 10]
+    outwcs = wcs.WCS()
+    outwcs.pixel_shape = shape
+    driz = drizzle.Drizzle(outwcs=outwcs)
 
-    test_square_with_point()
-    test_square_with_grid()
-    test_turbo_with_grid()
-    test_gaussian_with_grid()
-    test_lanczos_with_grid()
-    test_tophat_with_grid()
-    test_point_with_grid()
-    test_blot_with_point()
-    test_blot_with_default()
-    test_blot_with_lan3()
-    test_blot_with_lan5()
+    image = np.ones(shape)
+    inwcs = wcs.WCS()
+    inwcs.pixel_shape = shape
+
+    for i in range(32):
+        driz.add_image(image, inwcs)
+    assert driz.outcon.shape == (1, 10, 10)
+
+    driz.add_image(image, inwcs)
+    assert driz.outcon.shape == (2, 10, 10)
