@@ -1,16 +1,17 @@
-import sys
 import os.path
-import numpy as np
-import numpy.testing as npt
 
+import numpy as np
+from numpy.testing import assert_equal, assert_almost_equal
 from astropy import wcs
 from astropy.io import fits
 
 from drizzle import calc_pixmap
 
+
 TEST_DIR = os.path.abspath(os.path.dirname(__file__))
 DATA_DIR = os.path.join(TEST_DIR, 'data')
 
+
 def test_map_rectangular():
     """
     Make sure the initial index array has correct values
@@ -20,7 +21,9 @@ def test_map_rectangular():
 
     pixmap = np.indices((naxis1, naxis2), dtype='float32')
     pixmap = pixmap.transpose()
-    npt.assert_equal(pixmap[5,500], (500,5))
+
+    assert_equal(pixmap[5,500], (500,5))
+
 
 def test_map_to_self():
     """
@@ -28,8 +31,6 @@ def test_map_to_self():
     """
     input_file = os.path.join(DATA_DIR, 'input1.fits')
     input_hdu = fits.open(input_file)
-    input_header = input_hdu[1].header
-    input_shape = input_hdu[1].data.shape
 
     input_wcs = wcs.WCS(input_hdu[1].header)
     naxis1, naxis2 = input_wcs.pixel_shape
@@ -39,8 +40,12 @@ def test_map_to_self():
     ok_pixmap = ok_pixmap.transpose()
 
     pixmap = calc_pixmap.calc_pixmap(input_wcs, input_wcs)
-    npt.assert_equal(pixmap.shape, ok_pixmap.shape) # Got x-y transpose right
-    npt.assert_almost_equal(pixmap, ok_pixmap, decimal=5) # Mapping an array to itself
+
+    # Got x-y transpose right
+    assert_equal(pixmap.shape, ok_pixmap.shape)
+    # Mapping an array to itself
+    assert_almost_equal(pixmap, ok_pixmap, decimal=5)
+
 
 def test_translated_map():
     """
@@ -65,5 +70,8 @@ def test_translated_map():
     ok_pixmap = ok_pixmap.transpose()
 
     pixmap = calc_pixmap.calc_pixmap(first_wcs, second_wcs)
-    npt.assert_equal(pixmap.shape, ok_pixmap.shape) # Got x-y transpose right
-    npt.assert_almost_equal(pixmap, ok_pixmap, decimal=5) # Mapping an array to a translated array
+
+    # Got x-y transpose right
+    assert_equal(pixmap.shape, ok_pixmap.shape)
+    # Mapping an array to a translated array
+    assert_almost_equal(pixmap, ok_pixmap, decimal=5)
