@@ -1,13 +1,5 @@
-from __future__ import division, print_function, unicode_literals, absolute_import
-
-# SYSTEM
-import os
-import os.path
-
-# THIRD-PARTY
 import numpy as np
-from astropy import wcs
-from astropy.io import fits
+
 
 def find_keyword_extn(fimg, keyword, value=None):
     """
@@ -53,6 +45,7 @@ def find_keyword_extn(fimg, keyword, value=None):
     # desired EXTNAME value.
     return extnum
 
+
 def get_extn(fimg, extn=''):
     """
     Returns the FITS extension corresponding to extension specified in
@@ -104,6 +97,7 @@ def get_extn(fimg, extn=''):
 
     return _extn
 
+
 def get_keyword(fimg, keyword, default=None):
     """
     Return a keyword value from the header of an image,
@@ -140,6 +134,7 @@ def get_keyword(fimg, keyword, default=None):
 
     return value
 
+
 def is_blank(value):
     """
     Determines whether or not a value is considered 'blank'.
@@ -157,6 +152,7 @@ def is_blank(value):
     """
     return value.strip() == ""
 
+
 def parse_extn(extn=''):
     """
     Parse a string representing a qualified fits extension name as in the
@@ -197,6 +193,7 @@ def parse_extn(extn=''):
     else:
         return (lext[0], 1)
 
+
 def parse_filename(filename):
     """
     Parse out filename from any specified extensions.
@@ -218,13 +215,14 @@ def parse_filename(filename):
     if _indx > 0:
         # Read extension name provided
         _fname = filename[:_indx]
-        _extn = filename[_indx+1:-1]
+        _extn = filename[_indx + 1:-1]
     else:
         _fname = filename
         _extn = ''
 
     return _fname, _extn
 
+
 def set_pscale(the_wcs):
     """
     Calculates the plate scale from cdelt and the pc  matrix and adds
@@ -254,5 +252,5 @@ def set_pscale(the_wcs):
             pc = 1
 
     pccd = np.array(cdelt * pc)
-    scales = np.sqrt((pccd ** 2).sum(axis=0, dtype=np.float))
+    scales = np.sqrt((pccd ** 2).sum(axis=0, dtype=float))
     the_wcs.pscale = scales[0]
